@@ -10,14 +10,15 @@
 // Implementation.
 
 #include "cl_N.h"
+#include "cln/exception.h"
 
 namespace cln {
 
 // Cf. cl_N_p in cl_C_ring.cc.
 // But here, for better inlining in g++, it is preferrable to finish every
-// alternative with either "return cl_true;" or "return cl_false;".
+// alternative with either "return true;" or "return false;".
 
-inline cl_boolean cl_N_p (const cl_number& x)
+inline bool cl_N_p (const cl_number& x)
 {
 	if (!x.pointer_p())
 		switch (x.nonpointer_tag()) {
@@ -26,12 +27,12 @@ inline cl_boolean cl_N_p (const cl_number& x)
 		#if defined(CL_WIDE_POINTERS)
 		case cl_FF_tag:
 		#endif
-			return cl_true;
+			return true;
 		}
 	else
 		if (x.pointer_type()->flags & cl_class_flags_subclass_complex)
-			return cl_true;
-	return cl_false;
+			return true;
+	return false;
 }
 
 const cl_N& cl_N_As (const cl_number& x, const char * filename, int line)
@@ -40,7 +41,7 @@ const cl_N& cl_N_As (const cl_number& x, const char * filename, int line)
 		DeclareType(cl_N,x);
 		return x;
 	} else
-		cl_as_error(x,"a number",filename,line);
+		throw as_exception(x,"a number",filename,line);
 }
 
 }  // namespace cln
