@@ -21,7 +21,7 @@ const cl_I exquo (const cl_I& x, const cl_I& y)
 // Falls r<>0, Error.
 // Falls x,y verschiedene Vorzeichen haben, liefere -q, sonst q.
   var cl_I_div_t q_r = cl_divide(abs(x),abs(y));
-  if (!zerop(q_r.remainder)) { cl_error_exquo(x,y); }
+  if (!zerop(q_r.remainder)) { throw exquo_exception(x,y); }
   if (minusp(x) == minusp(y))
     { return q_r.quotient; }
     else
